Observation

Enum Observation 

pub enum Observation<Q> {
    Exact(Q),
    AtLeast(Q),
}
A resource observation that may be exact or only a safe lower bound.

Type Parameters

  • Q - Exact unsigned quantity used for measurements and accounting.

Examples

use qubit_budget::Observation;

let observation = Observation::AtLeast(4_u64);
assert_eq!(observation.exact(), None);
assert_eq!(observation.lower_bound(), 4);

Variants



Exact(Q)

The measured quantity is exact.

Tuple Fields

0: Q

Exact observed quantity.



AtLeast(Q)

The measured quantity is at least the contained lower bound.

Tuple Fields

0: Q

Proven lower bound for the observed quantity.

Implementations

Source

impl<Q> Observation<Q>
where Q: Copy + Debug,

pub const fn exact(self) -> Option<Q>

Returns the exact quantity, or None for a lower-bound observation.

Returns

Returns the exact quantity, or None for a lower-bound observation.

pub const fn lower_bound(self) -> Q

Returns the safe lower bound represented by this observation.

Returns

Returns the safe lower bound represented by this observation.