ResourceReleaseError

Enum ResourceReleaseError 

#[non_exhaustive]
pub enum ResourceReleaseError<R, Q = u64>
where Q: Copy + Debug,
{ InvalidRelease { resource: R, limit: Q, in_use: Q, requested: Q, }, }
Structured facts describing a pool release that exceeds current usage.

Type Parameters

  • R - Caller-defined resource identity retained by limits and errors.
  • Q - Exact unsigned quantity used for measurements and accounting.

Examples

use qubit_budget::ResourcePool;

let mut pool = ResourcePool::new("workers", 2_u64);
pool.try_acquire(1).expect("one worker should fit");
let error = pool.release(2).expect_err("only one worker is in use");
assert_eq!(error.in_use(), 1);
assert_eq!(error.requested(), 2);

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


InvalidRelease

A release request exceeded the amount currently in use.

Fields

resource: R

Resource associated with the failed release request.

limit: Q

Configured finite limit.

in_use: Q

Quantity in use before the failed release.

requested: Q

Quantity requested by the failed operation.

Implementations

Source

impl<R, Q> ResourceReleaseError<R, Q>
where Q: Copy + Debug,

pub const fn resource(&self) -> &R

Returns the resource associated with this failure.

Returns

Returns the resource associated with this failure.

pub fn into_resource(self) -> R

Consumes this error and returns its associated resource.

Returns

Consumes this error and returns its associated resource.

pub const fn limit(&self) -> Q

Returns the finite pool limit.

Returns

Returns the finite pool limit.

pub const fn in_use(&self) -> Q

Returns the amount in use before the invalid release.

Returns

Returns the amount in use before the invalid release.

pub const fn requested(&self) -> Q

Returns the requested release amount.

Returns

Returns the requested release amount.